SmallCharSet

Struct SmallCharSet 

pub struct SmallCharSet {
    pub bits: u64,
}
Represents a set of “small characters”, those with Unicode scalar values less than 64.

This is stored as a bitmap, with 1 bit for each value.

Fields

bits: u64

Implementations

Source

impl SmallCharSet

pub fn nonmember_prefix_len(&self, buf: &str) -> u32

Count the number of bytes of characters at the beginning of buf which are not in the set.

This functionality is used in BufferQueue::pop_except_from.

Examples
let set = small_char_set!(48 49 50); // '0' '1' '2'
// `test` is 4 chars, 😁 is 4 chars, then we meet a character in the set
let test_str = "test😁01232afd";
assert_eq!(set.nonmember_prefix_len(test_str), 8);