Enum html5ever::tree_builder::interface::QuirksMode
[−]
[src]
pub enum QuirksMode {
Quirks,
LimitedQuirks,
NoQuirks,
}A document's quirks mode.
Variants
QuirksLimitedQuirksNoQuirksTrait Implementations
impl Debug for QuirksMode[src]
impl Hash for QuirksMode[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for QuirksMode[src]
fn clone(&self) -> QuirksMode
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more